@@ -1,5 +1,5 @@
+use binprot::macros::{BinProtRead, BinProtWrite};
 use binprot::{BinProtRead, BinProtSize, BinProtWrite};
-use binprot_derive::{BinProtRead, BinProtWrite};
 
 fn test_roundtrip<T>(t: T, sz: usize, vs: Option<&[u8]>)
 where
@@ -24,11 +24,7 @@ fn breakfast1() {
     test_roundtrip(Pancakes(12), 1, Some(&[12]));
     test_roundtrip(Pancakes(0), 1, Some(&[0]));
     test_roundtrip(Pancakes(-1), 2, Some(&[255, 255]));
-    test_roundtrip(
-        Pancakes(12345678910111213),
-        9,
-        Some(&[252, 237, 189, 242, 93, 84, 220, 43, 0]),
-    );
+    test_roundtrip(Pancakes(12345678910111213), 9, Some(&[252, 237, 189, 242, 93, 84, 220, 43, 0]));
 }
 
 #[derive(BinProtRead, BinProtWrite, Debug, PartialEq)]
@@ -39,9 +35,7 @@ fn breakfast2() {
     test_roundtrip(
         MorePancakes(12, 3.141592, 1234567890123),
         18,
-        Some(&[
-            12, 122, 0, 139, 252, 250, 33, 9, 64, 252, 203, 4, 251, 113, 31, 1, 0, 0,
-        ]),
+        Some(&[12, 122, 0, 139, 252, 250, 33, 9, 64, 252, 203, 4, 251, 113, 31, 1, 0, 0]),
     );
 }
 
@@ -83,20 +77,13 @@ enum BreakfastMenu<T> {
 #[test]
 fn breakfast4() {
     let breakfast: BreakfastMenu<BreakfastMenu<i64>> =
-        BreakfastMenu::Any(BreakfastMenu::Everything {
-            eggs: 123,
-            pancakes: 456,
-        });
+        BreakfastMenu::Any(BreakfastMenu::Everything { eggs: 123, pancakes: 456 });
     let expected = [0, 5, 123, 254, 200, 1];
     test_roundtrip(breakfast, 6, Some(&expected));
     test_roundtrip(BreakfastMenu::<i64>::Nothing, 1, None);
     let expected = [1, 42];
     test_roundtrip(BreakfastMenu::<i64>::Eggs(42), 2, Some(&expected));
-    test_roundtrip(
-        binprot::WithLen(BreakfastMenu::<i64>::Eggs(42)),
-        3,
-        Some(&[2, 1, 42]),
-    );
+    test_roundtrip(binprot::WithLen(BreakfastMenu::<i64>::Eggs(42)), 3, Some(&[2, 1, 42]));
 }
 
 #[derive(BinProtWrite, BinProtRead, Debug, PartialEq)]
@@ -110,23 +97,13 @@ struct BreakfastItem {
 fn breakfast5() {
     let expected = [3, 101, 103, 103, 111, 18, 131, 192, 202, 33, 9, 64, 1];
     test_roundtrip(
-        BreakfastItem {
-            name: "egg".to_string(),
-            quantity: 3.1415,
-            large: true,
-        },
+        BreakfastItem { name: "egg".to_string(), quantity: 3.1415, large: true },
         13,
         Some(&expected),
     );
-    let expected = [
-        9, 99, 114, 111, 105, 115, 115, 97, 110, 116, 0, 0, 0, 0, 128, 28, 200, 192, 0,
-    ];
+    let expected = [9, 99, 114, 111, 105, 115, 115, 97, 110, 116, 0, 0, 0, 0, 128, 28, 200, 192, 0];
     test_roundtrip(
-        BreakfastItem {
-            name: "croissant".to_string(),
-            quantity: -12345.,
-            large: false,
-        },
+        BreakfastItem { name: "croissant".to_string(), quantity: -12345., large: false },
         19,
         Some(&expected),
     );
@@ -135,11 +112,7 @@ fn breakfast5() {
         177, 65, 0,
     ];
     test_roundtrip(
-        BreakfastItem {
-            name: "PainAuChocolat".to_string(),
-            quantity: 299792458.0,
-            large: false,
-        },
+        BreakfastItem { name: "PainAuChocolat".to_string(), quantity: 299792458.0, large: false },
         24,
         Some(&expected),
     );
@@ -159,12 +132,10 @@ enum BreakfastPoly<T> {
 
 #[test]
 fn breakfast6() {
-    let breakfast: BreakfastPoly<BreakfastPoly<i64>> = BreakfastPoly::Any(
-        BreakfastPoly::MorePancakes(MorePancakes(-123, 2.71828182846, 0)),
-    );
-    let expected = [
-        153, 101, 99, 0, 39, 152, 92, 190, 255, 133, 207, 95, 20, 139, 10, 191, 5, 64, 0,
-    ];
+    let breakfast: BreakfastPoly<BreakfastPoly<i64>> =
+        BreakfastPoly::Any(BreakfastPoly::MorePancakes(MorePancakes(-123, 2.71828182846, 0)));
+    let expected =
+        [153, 101, 99, 0, 39, 152, 92, 190, 255, 133, 207, 95, 20, 139, 10, 191, 5, 64, 0];
     test_roundtrip(breakfast, 19, Some(&expected));
     test_roundtrip(BreakfastPoly::<i64>::Nothing, 4, None);
     let expected = [93, 118, 212, 91, 42];
@@ -178,14 +149,11 @@ fn breakfast6() {
 
 #[test]
 fn breakfast7() {
-    let price_and_quantities: std::collections::HashMap<String, (i64, f64)> = [
-        ("croissant", (4, 1.23)),
-        ("JusDOrange", (1, 2.34)),
-        ("PainAuChocolat", (2, 1.45)),
-    ]
-    .iter()
-    .map(|(x, y)| (x.to_string(), *y))
-    .collect();
+    let price_and_quantities: std::collections::HashMap<String, (i64, f64)> =
+        [("croissant", (4, 1.23)), ("JusDOrange", (1, 2.34)), ("PainAuChocolat", (2, 1.45))]
+            .iter()
+            .map(|(x, y)| (x.to_string(), *y))
+            .collect();
     test_roundtrip(price_and_quantities.clone(), 64, None);
     let price_and_quantities: std::collections::BTreeMap<String, (i64, f64)> =
         price_and_quantities.into_iter().collect();
@@ -238,10 +206,8 @@ struct BreakfastStr {
 }
 #[test]
 fn breakfast_str() {
-    let breakfast_str = BreakfastStr {
-        str: "pancakes".to_string(),
-        bytes: "more-pancakes".to_string().into(),
-    };
+    let breakfast_str =
+        BreakfastStr { str: "pancakes".to_string(), bytes: "more-pancakes".to_string().into() };
     let expected = [
         8, 112, 97, 110, 99, 97, 107, 101, 115, 13, 109, 111, 114, 101, 45, 112, 97, 110, 99, 97,
         107, 101, 115,
